@@ -1,5 +1,5 @@
 package VideoLAN::LibVLC;
-use 5.008001;
+use v5.10;
 use strict;
 use warnings;
 use Carp;
@@ -8,7 +8,7 @@ use Socket qw( AF_UNIX SOCK_DGRAM );
 use IO::Handle;
 
 # ABSTRACT: Wrapper for libvlc.so
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 
 use Exporter::Extensible -exporter_setup => 1;
@@ -262,7 +262,7 @@ VideoLAN::LibVLC - Wrapper for libvlc.so
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -554,7 +554,7 @@ Michael Conrad <mike@nrdvana.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Michael Conrad.
+This software is copyright (c) 2023 by Michael Conrad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
